import { OnInit, AfterViewInit, Renderer2, ElementRef } from '@angular/core';
import { Sector, Line, RenderSector, Value, GaugeProps } from './shared/interfaces';
import { GaugeConfig } from './shared/config';
import * as i0 from "@angular/core";
export declare class GaugeComponent implements OnInit, AfterViewInit, GaugeProps {
    private _renderer;
    gauge: ElementRef;
    arrow: ElementRef;
    /**
     * Size/width of the gauge _in pixels_.
     */
    size: number;
    /**
     * The start/beginning of the scale arc _in degrees_. Default `225`
     */
    arcStart: number;
    /**
     * The end of the scale arc _in degrees_. Default: `135`
     */
    arcEnd: number;
    /**
     * Defines the coloring of specified sectors
     */
    sectors: Sector[];
    /**
     * The unit of the gauge (i.e. mph, psi, etc.)
     */
    unit: string;
    /**
     * Displays the current value as digital number inside the gauge
     */
    digitalDisplay: boolean;
    /**
     * Shows a red light when the specified limit is reached
     */
    activateRedLightAfter: number;
    /**
     * Enables the dark theme
     */
    darkTheme: boolean;
    /**
     * _(Not recommended)_ Alters the default configuration; This may lead to unexpected behavior; [GaugeConfig](./src/app/gauge/shared/config.ts)
     */
    config: GaugeConfig;
    viewBox: string;
    scaleLines: Line[];
    scaleValues: Value[];
    sectorArcs: RenderSector[];
    radius: number;
    center: number;
    scaleFactor: number;
    private _arcEnd;
    private _value;
    private _max;
    private _mappedSectors;
    constructor(_renderer: Renderer2);
    /**
     * The current value of the gauge
     */
    set value(val: number);
    get value(): number;
    /**
     * The maximal value of the gauge. It is suggested to use a number that is divisible by 10^n (e.g. 100, 1000, etc.)
     */
    set max(val: number);
    get max(): number;
    get arc(): string;
    get gaugeRotationAngle(): number;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    /**
     * Initialize gauge.
     */
    private _initialize;
    /**
     * Calculate arc.
     */
    private _arc;
    /**
     * Get angle coordinates (Cartesian coordinates).
     */
    private _getAngleCoor;
    /**
     * Calculate/translate the user-defined sectors to arcs.
     */
    private _calculateSectors;
    /**
     * Update the position of the arrow based on the current value.
     */
    private _updateArrowPos;
    /**
     * Rotate the gauge based on the start property. The CSS rotation, saves additional calculations with SVG.
     */
    private _rotateGauge;
    /**
     * Determine the scale factor (10^n number; i.e. if max = 9000 then scale_factor = 1000)
     */
    private _determineScaleFactor;
    /**
     * Determine the line frequency which represents after what angle we should put a line.
     */
    private _determineLineFrequency;
    /**
     * Checks whether the line (based on index) is big or small separator.
     */
    private _isSeparatorReached;
    /**
     * Creates the scale.
     */
    private _createScale;
    /**
     * Get the scale line color from the user-provided sectors definitions.
     */
    private _getScaleLineColor;
    /**
     * Add a scale line to the list that will be later rendered.
     */
    private _addScaleLine;
    /**
     * Add a scale value.
     */
    private _addScaleValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<GaugeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GaugeComponent, "ng2-gauge", never, { "size": { "alias": "size"; "required": false; }; "arcStart": { "alias": "arcStart"; "required": false; }; "arcEnd": { "alias": "arcEnd"; "required": false; }; "sectors": { "alias": "sectors"; "required": false; }; "unit": { "alias": "unit"; "required": false; }; "digitalDisplay": { "alias": "digitalDisplay"; "required": false; }; "activateRedLightAfter": { "alias": "activateRedLightAfter"; "required": false; }; "darkTheme": { "alias": "darkTheme"; "required": false; }; "config": { "alias": "config"; "required": false; }; "value": { "alias": "value"; "required": false; }; "max": { "alias": "max"; "required": false; }; }, {}, never, never, false, never>;
}
